using System;
using System.Collections;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using Syncfusion.Grouping;
using Syncfusion.Windows.Forms.Grid.Grouping;
using Syncfusion.Windows.Forms.Grid;

namespace WindowsApplication108
{
    public partial class Form1 : Form
    {
        public Form1()
        {
            InitializeComponent();
        }

        int nRows = 20;
        private void Form1_Load(object sender, EventArgs e)
        {
            #region Get the DataSource
            DataTable dt = new DataTable("MyTable");

            int nCols = 4;
            
            Random r = new Random(123345345);

            for (int i = 0; i < nCols; i++)
                dt.Columns.Add(new DataColumn(string.Format("Col{0}", i), typeof(int)));
            dt.Columns.Add(new DataColumn(this.primaryKeyColumnName, typeof(int)));
            dt.PrimaryKey = new DataColumn[] { dt.Columns[this.primaryKeyColumnName] };
            dt.Columns[this.primaryKeyColumnName].AutoIncrement = true;
            dt.Columns[this.primaryKeyColumnName].AutoIncrementSeed = 0;
            dt.Columns[this.primaryKeyColumnName].AutoIncrementStep = 1;

            for (int i = 0; i < nRows; ++i)
            {
                DataRow dr = dt.NewRow();
                for (int j = 0; j < nCols; j++)
                    dr[j] = r.Next(10);
                dr[nCols] = i;
                dt.Rows.Add(dr);
            }
            #endregion

            this.gridGroupingControl1.DataSource = dt;

            //Add an unbound column to hold the checkbox
            FieldDescriptor fd = new FieldDescriptor(this.unBoundColumnName, typeof(bool));
            this.gridGroupingControl1.TableDescriptor.UnboundFields.Add(fd);


            //add the events to manage the unbound field
            this.gridGroupingControl1.QueryValue += new FieldValueEventHandler(gridGroupingControl1_QueryValue);
            //normally you use grid.SaveValue to save values in an unbound field, but here we need
            //to use the values before teh row is fully committed, so we use CurrentCalleChanged instead.
           this.gridGroupingControl1.TableControlCurrentCellChanged += new GridTableControlEventHandler(gridGroupingControl1_TableControlCurrentCellChanged);

            //add the event to manage changing the existing records when new record added
            this.gridGroupingControl1.SourceListRecordChanged += new RecordChangedEventHandler(gridGroupingControl1_SourceListRecordChanged);

            this.gridGroupingControl1.TableDescriptor.Columns[this.primaryKeyColumnName].Width = 1; ;
            this.gridGroupingControl1.TableDescriptor.Columns["update"].Appearance.AddNewRecordFieldCell.CellType = "Static";

            this.gridGroupingControl1.TableControlDrawCellDisplayText += new GridTableControlDrawCellDisplayTextEventHandler(gridGroupingControl1_TableControlDrawCellDisplayText);
            this.gridGroupingControl1.QueryCellFormattedText += new GridCellTextEventHandler(gridGroupingControl1_QueryCellFormattedText);

           
        }

        void gridGroupingControl1_QueryCellFormattedText(object sender, GridCellTextEventArgs e)
        {
            GridTableCellStyleInfo style = e.Style as GridTableCellStyleInfo;
            Element el = style.TableCellIdentity.DisplayElement;
            if (el != null && el.Kind == DisplayElementKind.AddNewRecord
                && style.TableCellIdentity.Column != null
                && style.TableCellIdentity.Column.Name == unBoundColumnName)
            {
                e.Text = iNoOfCheckedCheckBox.ToString() ;
                e.Handled = true;
            }
        }

        void gridGroupingControl1_TableControlDrawCellDisplayText(object sender, GridTableControlDrawCellDisplayTextEventArgs e)
        {
            
        }


 

        void gridGroupingControl1_SourceListRecordChanged(object sender, RecordChangedEventArgs e)
        {
            //check if record was added with a checked update field.
            if (e.Action == RecordChangedType.Added )
            {
                
                GridGroupingControl grid = sender as GridGroupingControl;
                if(grid != null)
                {
                    foreach (Record rec in grid.Table.FilteredRecords)
                    {
                        if(Convert.ToBoolean(rec.GetValue(unBoundColumnName)))
                        {
                            foreach(GridColumnDescriptor cd in grid.TableDescriptor.Columns)
                            {
                                if (cd.MappingName != primaryKeyColumnName
                                    && cd.MappingName != unBoundColumnName )
                                {
                                    rec.SetValue(cd.FieldDescriptor,e.Record.GetValue(cd.MappingName) );
                                }
                            }
                            
                        }
                    }
                }
                //If you want to delete the Newly added row then call the Record.Delete method.
                //e.Record.Delete();  
            }
        }



        private string unBoundColumnName = "update";
        private string primaryKeyColumnName = "primaryKey";
        private Dictionary<int, bool> unboundValues = new Dictionary<int,bool>();
        private int iNoOfCheckedCheckBox = 0;
        void gridGroupingControl1_TableControlCurrentCellChanged(object sender, GridTableControlEventArgs e)
        {
            GridCurrentCell cc = e.TableControl.GetNestedCurrentCell();
            
            int field = e.TableControl.TableDescriptor.ColIndexToField(cc.ColIndex);
            if (e.TableControl.TableDescriptor.Fields[field].Name == unBoundColumnName)
            {

                GridTableCellStyleInfo style = e.TableControl.GetTableViewStyleInfo(cc.RowIndex, cc.ColIndex);
                Record rec = style.TableCellIdentity.DisplayElement.GetRecord();
               // StoreUnboundValue(rec, style.CellValue);
                object key = rec.GetValue(primaryKeyColumnName);
                if (key != null && key != DBNull.Value)
                {
                    int keyValue = Convert.ToInt32(key);
                    bool b = Convert.ToBoolean(style.CellValue);
                    if (unboundValues.ContainsKey(keyValue))
                    {   
                        unboundValues[keyValue] = b;
                    }
                    else
                    {
                        unboundValues.Add(keyValue, b );
                    }
                    if (b)
                    {
                        iNoOfCheckedCheckBox++;
                    }
                    else
                        iNoOfCheckedCheckBox--;

                } 
            }
        }



        void gridGroupingControl1_QueryValue(object sender, FieldValueEventArgs e)
        {
            if(e.Field.Name == this.unBoundColumnName)
            {
                object key = e.Record.GetValue(primaryKeyColumnName);
                if (key != null && key != DBNull.Value)
                {
                    int keyValue = Convert.ToInt32(key);
                    e.Value = unboundValues.ContainsKey(keyValue)
                        ? e.Value = unboundValues[Convert.ToInt32(key)] : e.Value = false;
                }
                else
                    e.Value = false;
            }
        }
    }
}